@@ -7,7 +7,7 @@
 # http://search.cpan.org/dist/Devel-NYTProf/
 #
 ###########################################################
-# $Id: Util.pm 998 2009-12-24 14:40:14Z tim.bunce $
+# $Id$
 ###########################################################
 package Devel::NYTProf::Util;
 
@@ -38,9 +38,9 @@ use base qw'Exporter';
 use Carp;
 use Cwd qw(getcwd);
 use List::Util qw(sum);
-#use UNIVERSAL qw( isa can VERSION );
+use Devel::NYTProf::Core;
 
-our $VERSION = '3.01';
+our $VERSION = '4.00';
 
 our @EXPORT_OK = qw(
     fmt_float
@@ -52,6 +52,7 @@ our @EXPORT_OK = qw(
     get_alternation_regex
     get_abs_paths_alternation_regex
     html_safe_filename
+    trace_level
 );
 
 
@@ -95,12 +96,18 @@ sub make_path_strip_editor {
     my @inc = @$inc_ref
         or return;
 
-    my $inc_regex = get_abs_paths_alternation_regex(\@inc);
+    our %make_path_strip_editor_cache;
+    my $key = join "\t", $anchor, $replacement, @inc;
 
-    # anchor at start, capture anchor
-    $inc_regex = qr{($anchor)$inc_regex};
+    return $make_path_strip_editor_cache{$key} ||= do {
 
-    return sub { $_[0] =~ s{$inc_regex}{$1$replacement} };
+        my $inc_regex = get_abs_paths_alternation_regex(\@inc);
+
+        # anchor at start, capture anchor
+        $inc_regex = qr{($anchor)$inc_regex};
+
+        sub { $_[0] =~ s{$inc_regex}{$1$replacement} };
+    };
 }
 
 
@@ -163,14 +170,16 @@ sub fmt_float {
 
 
 # XXX undocumented hack that may become to an option one day
-my $fmt_time_opt = $ENV{NYTPROF_FMT_TIME}; # e.g., '%fs'
+# Useful for making the time data more easily parseable
+my $fmt_time_opt = $ENV{NYTPROF_FMT_TIME}; # e.g., '%f' for 'raw' times
 
 sub fmt_time {
     my ($sec, $width) = @_;
     $width = '' unless defined $width;
-    return sprintf "%$width.0fs", 0    unless $sec;
+    return undef if not defined $sec;
     return '-'.fmt_time(-$sec, $width) if $sec < 0; # negative value, can happen
     return sprintf $fmt_time_opt, $sec if $fmt_time_opt;
+    return sprintf "%$width.0fs", 0    unless $sec;
     return sprintf "%$width.0fns",                              $sec * 1e9 if $sec < 1e-6;
     return sprintf "%$width.0f&micro;s",                        $sec * 1e6 if $sec < 1e-3;
     return sprintf "%$width.*fms", 3 - length(int($sec * 1e3)), $sec * 1e3 if $sec < 1;
